Class: Howdoc::Step::Narrated
- Inherits:
-
Struct
- Object
- Struct
- Howdoc::Step::Narrated
- Defined in:
- lib/howdoc/step.rb
Overview
A step as one language tells it: the sentence composed, the illustration named as that language's guide refers to it. This is what a template is handed, so a template never has to know which language it is rendering.
Instance Attribute Summary collapse
-
#arrival ⇒ Object
Returns the value of attribute arrival.
-
#html ⇒ Object
Returns the value of attribute html.
-
#number ⇒ Object
Returns the value of attribute number.
-
#screenshot ⇒ Object
Returns the value of attribute screenshot.
Instance Method Summary collapse
Instance Attribute Details
#arrival ⇒ Object
Returns the value of attribute arrival
15 16 17 |
# File 'lib/howdoc/step.rb', line 15 def arrival @arrival end |
#html ⇒ Object
Returns the value of attribute html
15 16 17 |
# File 'lib/howdoc/step.rb', line 15 def html @html end |
#number ⇒ Object
Returns the value of attribute number
15 16 17 |
# File 'lib/howdoc/step.rb', line 15 def number @number end |
#screenshot ⇒ Object
Returns the value of attribute screenshot
15 16 17 |
# File 'lib/howdoc/step.rb', line 15 def screenshot @screenshot end |
Instance Method Details
#empty? ⇒ Boolean
16 17 18 |
# File 'lib/howdoc/step.rb', line 16 def empty? html.nil? && screenshot.nil? end |